parso: Python Parser
====================

Description
-----------

Parso is a Python parser that supports error recovery and round-trip
parsing for different Python versions (in multiple Python versions).
Parso is also able to list multiple syntax errors in your python file.

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/parso/

